==> dkaframework-1.0.384.tgz: package/Example/index.js <==
import DKA, { Utils, Server, Functions, Hardware, Options, Config, Database } from "./../src/Framework/Module/index.module.d";
import path from "path";
import moment from "moment-timezone";

(async () => {
    let NFC = await new Hardware.Nfc({
        state : Options.SERVER_STATE_DEVELOPMENT,
    });

    /*await NFC.Write({ data : "companyId:ND#type:GLOBAL#name:YOVANGGA ANANDHIKA", dataLength : 48 }, async (response) => {
        await console.log(response)
    });*/

    /*await NFC.Write({ data : { tN : 291992992, mId : 2, pD : 2 }, blockNumber : 8, dataLength : 48 }, async (response) => {
        await console.log(response)
    })*/

    /*await NFC.Write({ data : { cId : "NBP", tC : "GLOBAL", nik : 12, n : "IHWAN" }, blockNumber : 4, dataLength : 48 }, async (response) => {
        console.log(response)

    });*/

    await NFC.Read({ blockNumber : 4, length : 48 }, async (data) => {
        console.log(data)
    });

    Utils.estimationCostFromTime({
        data : {
            hours : 1
        }
    })

    /*Utils.estimationCostFromTime({
        data : {
            hours : 1
        }
    })*/




    /*let firestore = new Database.Google.Firestore();
    await firestore.collection("DKA").get()
        .then(async (querySnapshot) => {
            querySnapshot.forEach(function(doc) {
                // doc.data() is never undefined for query doc snapshots
                console.log(doc.id, " => ", doc.data());

            });
        }).catch(async (error) => {
            console.log(error)
        })*/



})();

==> dkaframework-1.0.386.tgz: package/Example/index.js <==
import DKA, { Utils, Server, Functions, Hardware, Options, Config, Database } from "./../src/Framework/Module/index.module.d";
import path from "path";
import moment from "moment-timezone";

(async () => {


    /*Server({
        serverEngine : Options.NTP_CORE_ENGINE,
        serverPort : 124,
        app : async (ntp) => {

        },
    })
        .then(async (result) => {
            console.log(result)
        }).catch(async (error) => {
            console.log(error)
    })*/
    /*let NFC = await new Hardware.Nfc({
        state : Options.SERVER_STATE_DEVELOPMENT,
    });

    NFC.Trigger("NFC_ERROR", async (error) => {
        console.log(error)
    })*/

    /*await NFC.Write({ data : "companyId:ND#type:GLOBAL#name:YOVANGGA ANANDHIKA", dataLength : 48 }, async (response) => {
        await console.log(response)
    });*/

    /*await NFC.Write({ data : { cId : 1, tC : "MEMBER", mId : 2 }, blockNumber : 4, dataLength : 48 }, async (response) => {
        await console.log(response)
    })*/

    /*await NFC.Write({ data : { cId : "ND", tC : "GLOBAL", nik : 4, n : "ARLAN" }, blockNumber : 4, dataLength : 48 }, async (response) => {
        console.log(response)

    });*/

    /*await NFC.Read({ blockNumber : 4, length : 48 }, async (data) => {
        console.log(data)
    });*/


    Utils.estimationCostFromTime({
        data : {
            hours : 1
        }
    })

    /*Utils.estimationCostFromTime({
        data : {
            hours : 1
        }
    })*/




    /*let firestore = new Database.Google.Firestore();
    await firestore.collection("DKA").get()
        .then(async (querySnapshot) => {
            querySnapshot.forEach(function(doc) {
                // doc.data() is never undefined for query doc snapshots
                console.log(doc.id, " => ", doc.data());

            });
        }).catch(async (error) => {
            console.log(error)
        })*/



})();
